/*
 *  Licensed Materials - Property of IBM
 *
 *  (C) COPYRIGHT IBM Corp. 2005  All rights reserved.
 *
 *  US Government Users Restricted Rights - Use, duplication or
 *  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 */

package com.ibm.almaden;

import java.util.*;
import COM.ibm.db2.app.*;

/**
 * 
 * Send email.
 * 
 * @author <A HREF="mailto:jussi@almaden.ibm.com">Jussi Myllymaki</a>
 * @version $Revision: 1 $ $Date: 5/09/05 5:41p $
 */

public class SendMailUDF extends UDF {

	/**
	 * UDF for sending email to recipient. Attach files to email message if requested.
	 * @param	gateway			Address of email gateway.
	 * @param	sender			Sender's email address.
	 * @param	senderPersonal	Sender's personal name.
	 * @param	recipient		Recipient of the email.
	 * @param	subject			Subject of the message.
	 * @param	body			Body of the message.
	 * @param	att1			Attachment 1.
	 * @param	attName1		Name (Content-Disposition) of attachment 1.
	 * @param	att2			Attachment 2.
	 * @param	attName2		Name (Content-Disposition) of attachment 2.
	 * @param	att3			Attachment 3.
	 * @param	attName3		Name (Content-Disposition) of attachment 3.
	 */
	public synchronized void send(String gateway, String sender, String senderPersonal,
					     String recipient, String subject, String body, String att1, String attName1,
					     String att2, String attName2, String att3, String attName3, int resultCode)
		throws Exception {

		Vector attachments = new Vector();
		Vector attachmentNames = new Vector();

		if (att1 != null && att1.length() > 0) {
			attachments.add(att1);
			attachmentNames.add(attName1);
		}
		if (att2 != null && att2.length() > 0) {
			attachments.add(att2);
			attachmentNames.add(attName2);
		}
		if (att3 != null && att3.length() > 0) {
			attachments.add(att3);
			attachmentNames.add(attName3);
		}

		SendMail.send(gateway, sender, senderPersonal, recipient, subject, body, attachments, attachmentNames);

		set(13, 0);

    }

	/**
	 * UDF for sending email to recipient. Attach files to email message if requested.
	 * @param	gateway			Address of email gateway.
	 * @param	sender			Sender's email address.
	 * @param	senderPersonal	Sender's personal name.
	 * @param	recipient		Recipient of the email.
	 * @param	subject			Subject of the message.
	 * @param	body			Body of the message.
	 * @param	att1			Attachment 1.
	 * @param	attName1		Name (Content-Disposition) of attachment 1.
	 * @param	att2			Attachment 2.
	 * @param	attName2		Name (Content-Disposition) of attachment 2.
	 * @param	att3			Attachment 3.
	 * @param	attName3		Name (Content-Disposition) of attachment 3.
	 */
	public synchronized void send(String gateway, String sender, String senderPersonal,
					     String recipient, String subject, String body, Clob att1, String attName1,
					     Clob att2, String attName2, Clob att3, String attName3, int resultCode)
		throws Exception {

		Vector attachments = new Vector();
		Vector attachmentNames = new Vector();

		if (att1 != null && att1.size() > 0) {
			attachments.add(att1.getReader());
			attachmentNames.add(attName1);
		}
		if (att2 != null && att2.size() > 0) {
			attachments.add(att2.getReader());
			attachmentNames.add(attName2);
		}
		if (att3 != null && att3.size() > 0) {
			attachments.add(att3.getReader());
			attachmentNames.add(attName3);
		}

		SendMail.send(gateway, sender, senderPersonal, recipient, subject, body, attachments, attachmentNames);
		
		set(13, 0);

    }

}

/**
 * $History: SendMailUDF.java $
 * 
 * *****************  Version 1  *****************
 * User: Jussi        Date: 5/09/05    Time: 5:41p
 * Created in $/DB2SOAP/Development/SQL2Excel/com/ibm/almaden
 * Initial revision. Copied some content from Andes project.
 */
